@@ -172,6 +172,7 @@ class ImageService(MapService):
     def service_type(self):
         return 'image'
 
+
 class WMSService(MapService):
     """
     This class represents a WMS service object.
@@ -284,7 +285,7 @@ def get_services(config_path=None, include_default=True, contains=None, sources=
 
     source_objs = None
 
-    if sources is not None:
+    if sources:
         source_objs = sources
 
     elif config_path is None:
