@@ -422,6 +422,22 @@ def raster_to_categorical_points(arr, cats: dict, dim: str = 'data'):
     return df
 
 
+def load_in_memory(df):
+    """
+    Compute dask data frame.
+
+    Parameters
+    ----------
+    df: dask.dataframe or dask_geopandas.GeoDataFrame object
+
+    Returns
+    -------
+    computed_df: pandas.DataFrame or geopandas.GeoDataFrame object
+    """
+    df = df.compute()
+    return df
+
+
 _transforms = {
     'reproject_raster': reproject_raster,
     'reproject_vector': reproject_vector,
@@ -436,7 +452,8 @@ _transforms = {
     'add_projected_buffered_extent': add_projected_buffered_extent,
     'select_by_attributes': select_by_attributes,
     'polygon_to_line': polygon_to_line,
-    'raster_to_categorical_points': raster_to_categorical_points
+    'raster_to_categorical_points': raster_to_categorical_points,
+    'load_in_memory': load_in_memory,
 }
 
 
